%% Load and visualise SED data
%% Pim Willemsen, Deltares, UTwente 
%% Only use this data and script by referring to: 
% Martin J. Baptist, T. Gerkema, B.C. van Prooijen, D.S. van Maren, M. van Regteren, K. Schulz, I. Colosimo, J. Vroom, T. van Kessel, B. Grasmeijer, P. Willemsen, K. Elschot, A.V. de Groot, J. Cleveringa, E.M.M. van Eekelen, F. Schuurman, H.J. de Lange, M.E.B. van Puijenbroek, Beneficial use of dredged sediment to enhance salt marsh development by applying a Mud Motor, Ecological Engineering, Volume 127, 2019, Pages 312-323, ISSN 0925-8574, https://doi.org/10.1016/j.ecoleng.2018.11.019.
% Willemsen, P. W. J. M., Borsje, B. W., Hulscher, S. J. M. H., Van Der Wal, D., Zhu, Z., Oteman, B., ... Bouma, T. J. (2018). Quantifying Bed Level Change at the Transition of Tidal Flat and Salt Marsh: Can We Understand the Lateral Location of the Marsh Edge? Journal of geophysical research. Earth surface, 123(10), 2509-2524. https://doi.org/10.1029/2018JF004742


clear all, close all, clc

%% Load data
main_folder = 'N:\Projects\1209500\1209751\B. Measurements and calculations\SEDs\fieldtrip_SED_analysis\SED';
% SED182_ma = load([main_folder,'\bed_level_moving_average_182-0001.txt']);
% SED183_ma = load([main_folder,'\bed_level_moving_average_183-0001.txt']);
% SED184_ma = load([main_folder,'\bed_level_moving_average_184-0001.txt']);
% SED185_ma = load([main_folder,'\bed_level_moving_average_185-0001.txt']);

SED182 = load([main_folder,'\bed_level_unprocessed182-0001.txt']);
SED183 = load([main_folder,'\bed_level_unprocessed183-0001.txt']);
SED184 = load([main_folder,'\bed_level_unprocessed184-0001.txt']);
SED185 = load([main_folder,'\bed_level_unprocessed185-0001.txt']);

SED182_2 = load([main_folder,'\bed_level_unprocessed182-0002.txt']);
SED183_2 = load([main_folder,'\bed_level_unprocessed183-0002.txt']);
SED184_2 = load([main_folder,'\bed_level_unprocessed184-0002.txt']);
SED185_2 = load([main_folder,'\bed_level_unprocessed185-0002.txt']);
SED186_2 = load([main_folder,'\bed_level_unprocessed186-0002.txt']);

%% Remove endpoints/starting points
SED186_2(1:300,2:end) = NaN;

SED185_2(495:497,2:end) = NaN;
SED185_2(3200:3202,2:end) = NaN;
SED185_2(4182:4215,2:end) = NaN;

SED184_2(1675:1696,2:end) = NaN;
SED184_2(3200:3202,2:end) = NaN;
SED184_2(3436:3447,2:end) = NaN;
SED184_2(5163:5196,2:end) = NaN;

SED183_2(4608:4696,2:end) = NaN;
%% Load other data
% load pressure data
load('N:\Projects\1209500\1209751\B. Measurements and calculations\SEDs\MudMotorPressures.mat');

% load weather data
weather_dat = load('N:\Projects\1209500\1209751\B. Measurements and calculations\SEDs\KNMI_20171113_hourly_Lauwersoog_clean.txt');
weather_Tvec = datenum(2017,7,1,0,0,0):datenum(0,0,0,1,0,0):datenum(2017,9,1,23,0,0);

% insert DGPS data
DGPS182.bed = [0.4275, 0.4545, 0.376];
DGPS182.sen = [0.6133, nan, 0.584];
DGPS182.top = [0.9600, 0.9550, 0.9605];

DGPS183.bed = [0.9007, 0.9570, 0.8935];
DGPS183.sen = [0.9363, nan, 1.186];
DGPS183.top = [1.5213, 1.5580, 1.524667];

DGPS184.bed = [0.3068, 0.4080, 0.3545];
DGPS184.sen = [0.5610, nan, 0.566];
DGPS184.top = [0.9170, 0.8825, 0.8975];

DGPS185.bed = [0.7667, 0.8280, 0.763];
DGPS185.sen = [0.9363, nan, 0.909];
DGPS185.top = [1.2823, 1.3045, 1.288333];

DGPS186.bed = [nan   , 0.2685, 0.2015];
DGPS186.sen = [nan   , nan, 0.388];
DGPS186.top = [nan   , 0.7570, 0.746];

DGPS.date1 = [2017,07,13,00,00,00]
DGPS.date2 = [2017,08,30,00,00,00]
DGPS.date3 = [2018,01,10,00,00,00]

% find first data point ~isnan, to get the reference bed level
SED182_ref = find(~isnan(SED182(:,2)),1);
SED183_ref = find(~isnan(SED183(:,2)),1);
SED184_ref = find(~isnan(SED184(:,2)),1);
SED185_ref = find(~isnan(SED185(:,2)),1);

SED182_2_ref = find(~isnan(SED182_2(:,2)),1);
SED183_2_ref = find(~isnan(SED183_2(:,2)),1);
SED184_2_ref = find(~isnan(SED184_2(:,2)),1);
SED185_2_ref = find(~isnan(SED185_2(:,2)),1);
SED186_2_ref = find(~isnan(SED186_2(:,2)),1);

% find last data point ~isnan, to get the end bed level of a data series
SED182_end = find(~isnan(SED182(:,2)),1,'last');
SED183_end = find(~isnan(SED183(:,2)),1,'last');
SED184_end = find(~isnan(SED184(:,2)),1,'last');
SED185_end = find(~isnan(SED185(:,2)),1,'last');

SED182_2_end = find(~isnan(SED182_2(:,2)),1,'last');
SED183_2_end = find(~isnan(SED183_2(:,2)),1,'last');
SED184_2_end = find(~isnan(SED184_2(:,2)),1,'last');
SED185_2_end = find(~isnan(SED185_2(:,2)),1,'last');
SED186_2_end = find(~isnan(SED186_2(:,2)),1,'last');

% moving average over unprocessed data
window = 49;
SED182_maday = nanfastsmooth(SED182(:,2)-SED182(SED182_ref,2),window,1,1);
SED183_maday = nanfastsmooth(SED183(:,2)-SED183(SED183_ref,2),window,1,1);
SED184_maday = nanfastsmooth(SED184(:,2)-SED184(SED184_ref,2),window,1,1);
SED185_maday = nanfastsmooth(SED185(:,2)-SED185(SED185_ref,2),window,1,1);


SED182_2_maday = nanfastsmooth(SED182_2(:,2)-SED182_2(SED182_2_ref,2),window,1,1);
SED183_2_maday = nanfastsmooth(SED183_2(:,2)-SED183_2(SED183_2_ref,2),window,1,1);
SED184_2_maday = nanfastsmooth(SED184_2(:,2)-SED184_2(SED184_2_ref,2),window,1,1);
SED185_2_maday = nanfastsmooth(SED185_2(:,2)-SED185_2(SED185_2_ref,2),window,1,1);
SED186_2_maday = nanfastsmooth(SED186_2(:,2)-SED186_2(SED186_2_ref,2),window,1,1);

% combine multiple datasets
SED182_comb = [SED182(:,2)-SED182(SED182_ref,2);SED182(SED182_end,2)-SED182(SED182_ref,2)+SED182_2(:,2)-SED182_2(SED182_2_ref,2)];
SED183_comb = [SED183(:,2)-SED183(SED183_ref,2);SED183(SED183_end,2)-SED183(SED183_ref,2)+SED183_2(:,2)-SED183_2(SED183_2_ref,2)];
SED184_comb = [SED184(:,2)-SED184(SED184_ref,2);SED184(SED184_end,2)-SED184(SED184_ref,2)+SED184_2(:,2)-SED184_2(SED184_2_ref,2)];
SED185_comb = [SED185(:,2)-SED185(SED185_ref,2);SED185(SED185_end,2)-SED185(SED185_ref,2)+SED185_2(:,2)-SED185_2(SED185_2_ref,2)];
SED186_comb = [                                                      SED186_2(:,2)-SED186_2(SED186_2_ref,2)];

SED182_combT = [SED182(:,6:11);SED182_2(:,6:11)];
SED183_combT = [SED183(:,6:11);SED183_2(:,6:11)];
SED184_combT = [SED184(:,6:11);SED184_2(:,6:11)];
SED185_combT = [SED185(:,6:11);SED185_2(:,6:11)];
SED186_combT = [               SED186_2(:,6:11)];

%% Plot data 
%Fieldwork 1
figure;
plot(datenum(SED184(:,6:11)),SED184(:,2)-SED184(SED184_ref,2),'.','color',[0.75,0.75,0.75]);
hold on;
plot(datenum(SED182(:,6:11)),SED182(:,2)-SED182(SED182_ref,2),'.','color',[0.4,0.4,0.4]);
plot(datenum(SED185(:,6:11)),SED185(:,2)-SED185(SED185_ref,2),'.','color',[0.25,0.25,1]);
plot(datenum(SED183(:,6:11)),SED183(:,2)-SED183(SED183_ref,2),'.','color',[1,0.25,0.25]);

plot(datenum(SED184(:,6:11)),SED184_maday,'color',[0.5,0.5,0.5]);
plot(datenum(SED182(:,6:11)),SED182_maday,'color',[0,0,0]);
plot(datenum(SED185(:,6:11)),SED185_maday,'b');
plot(datenum(SED183(:,6:11)),SED183_maday,'r');

datetick('x','dd-mm-yyyy');
box on; grid on

ylabel('bed level variation [mm]','fontsize',14)
xlabel('time [dd-mm-yyyy]','fontsize',14);
legend('A 60m - top bedform','A 60m - bottom bedform','B 100m','C 100m','A 60m - top bedform (24h mov. avg.)','A 60m - bottom bedform (24h mov. avg.)','B 100m (24h mov. avg.)','C 100m (24h mov. avg.)','location','northwest');
set(gca,'fontsize',14)

%Fieldwork 2
figure;
plot(datenum(SED184_2(:,6:11)),SED184_2(:,2)-SED184_2(SED184_2_ref,2),'.','color',[0.75,0.75,0.75]);
hold on;
plot(datenum(SED182_2(:,6:11)),SED182_2(:,2)-SED182_2(SED182_2_ref,2),'.','color',[0.4,0.4,0.4]);
plot(datenum(SED186_2(:,6:11)),SED186_2(:,2)-SED186_2(SED186_2_ref,2),'.','color',[0,0.5,0]);
plot(datenum(SED185_2(:,6:11)),SED185_2(:,2)-SED185_2(SED185_2_ref,2),'.','color',[0.25,0.25,1]);
plot(datenum(SED183_2(:,6:11)),SED183_2(:,2)-SED183_2(SED183_2_ref,2),'.','color',[1,0.25,0.25]);

plot(datenum(SED184_2(:,6:11)),SED184_2_maday,'color',[0.5,0.5,0.5]);
plot(datenum(SED182_2(:,6:11)),SED182_2_maday,'color',[0,0,0]);
plot(datenum(SED186_2(:,6:11)),SED186_2_maday,'color','g');
plot(datenum(SED185_2(:,6:11)),SED185_2_maday,'b');
plot(datenum(SED183_2(:,6:11)),SED183_2_maday,'r');

datetick('x','dd-mm-yyyy');
box on; grid on

ylabel('bed level variation [mm]','fontsize',14)
xlabel('time [dd-mm-yyyy]','fontsize',14);
legend('A 60m - top bedform','A 60m - bottom bedform','A 100m','B 100m','C 100m', ...
    'A 60m - top bedform (24h mov. avg.)','A 60m - bottom bedform (24h mov. avg.)', ...
    'A 100m (24h mov. avg.)', 'B 100m (24h mov. avg.)','C 100m (24h mov. avg.)', ...
    'location','northeast');
set(gca,'fontsize',14)


%% plot data with DGPS
% Fieldwork 1
figure;
plot(datenum(SED184(:,6:11)),SED184(:,2)-SED184(SED184_ref,2),'.','color',[0.75,0.75,0.75]);
hold on;
plot(datenum(SED182(:,6:11)),SED182(:,2)-SED182(SED182_ref,2),'.','color',[0.4,0.4,0.4]);
plot(datenum(SED185(:,6:11)),SED185(:,2)-SED185(SED185_ref,2),'.','color',[0.25,0.25,1]);
plot(datenum(SED183(:,6:11)),SED183(:,2)-SED183(SED183_ref,2),'.','color',[1,0.25,0.25]);

plot(datenum(SED184(:,6:11)),SED184_maday,'color',[0.5,0.5,0.5]);
plot(datenum(SED182(:,6:11)),SED182_maday,'color',[0,0,0]);
plot(datenum(SED185(:,6:11)),SED185_maday,'b');
plot(datenum(SED183(:,6:11)),SED183_maday,'r');

plot([datenum(DGPS.date1),datenum(DGPS.date2)],(DGPS182.bed(1:2)-DGPS182.bed(1)).*1000,'--','color',[0.4,0.4,0.4]);
plot([datenum(DGPS.date1),datenum(DGPS.date2)],(DGPS182.top(1:2)-DGPS182.top(1)).*1000,'-.','color',[0.4,0.4,0.4]);

plot([datenum(DGPS.date1),datenum(DGPS.date2)],(DGPS183.bed(1:2)-DGPS183.bed(1)).*1000,'--','color',[1,0.25,0.25]);
plot([datenum(DGPS.date1),datenum(DGPS.date2)],(DGPS183.top(1:2)-DGPS183.top(1)).*1000,'-.','color',[1,0.25,0.25]);

plot([datenum(DGPS.date1),datenum(DGPS.date2)],(DGPS184.bed(1:2)-DGPS184.bed(1)).*1000,'--','color',[0.75,0.75,0.75]);
plot([datenum(DGPS.date1),datenum(DGPS.date2)],(DGPS184.top(1:2)-DGPS184.top(1)).*1000,'-.','color',[0.75,0.75,0.75]);

plot([datenum(DGPS.date1),datenum(DGPS.date2)],(DGPS185.bed(1:2)-DGPS185.bed(1)).*1000,'--','color',[0.25,0.25,1]);
plot([datenum(DGPS.date1),datenum(DGPS.date2)],(DGPS185.top(1:2)-DGPS185.top(1)).*1000,'-.','color',[0.25,0.25,1]);

datetick('x','dd-mm-yyyy');
box on; grid on

ylabel('bed level variation [mm]','fontsize',14)
xlabel('time [dd-mm-yyyy]','fontsize',14);
legend('A 60m - top bedform','A 60m - bottom bedform','B 100m','C 100m','A 60m - top bedform (24h mov. avg.)','A 60m - bottom bedform (24h mov. avg.)','B 100m (24h mov. avg.)','C 100m (24h mov. avg.)','DGPS bed SED', 'DGPS top SED','location','northwest');
set(gca,'fontsize',14)

% Fieldwork 2
figure;
plot(datenum(SED184_2(:,6:11)),SED184_2(:,2)-SED184_2(SED184_2_ref,2),'.','color',[0.75,0.75,0.75]);
hold on;
plot(datenum(SED182_2(:,6:11)),SED182_2(:,2)-SED182_2(SED182_2_ref,2),'.','color',[0.4,0.4,0.4]);
plot(datenum(SED186_2(:,6:11)),SED186_2(:,2)-SED186_2(SED186_2_ref,2),'.','color',[0,0.5,0]);
plot(datenum(SED185_2(:,6:11)),SED185_2(:,2)-SED185_2(SED185_2_ref,2),'.','color',[0.25,0.25,1]);
plot(datenum(SED183_2(:,6:11)),SED183_2(:,2)-SED183_2(SED183_2_ref,2),'.','color',[1,0.25,0.25]);

plot(datenum(SED184_2(:,6:11)),SED184_2_maday,'color',[0.5,0.5,0.5]);
plot(datenum(SED182_2(:,6:11)),SED182_2_maday,'color',[0,0,0]);
plot(datenum(SED186_2(:,6:11)),SED186_2_maday,'color','g');
plot(datenum(SED185_2(:,6:11)),SED185_2_maday,'b');
plot(datenum(SED183_2(:,6:11)),SED183_2_maday,'r');

plot([datenum(DGPS.date2),datenum(DGPS.date3)],(DGPS182.bed(2:3)-DGPS182.bed(2)).*1000,'--','color',[0.4,0.4,0.4]);
plot([datenum(DGPS.date2),datenum(DGPS.date3)],(DGPS182.top(2:3)-DGPS182.top(2)).*1000,'-.','color',[0.4,0.4,0.4]);

plot([datenum(DGPS.date2),datenum(DGPS.date3)],(DGPS183.bed(2:3)-DGPS183.bed(2)).*1000,'--','color',[1,0.25,0.25]);
plot([datenum(DGPS.date2),datenum(DGPS.date3)],(DGPS183.top(2:3)-DGPS183.top(2)).*1000,'-.','color',[1,0.25,0.25]);

plot([datenum(DGPS.date2),datenum(DGPS.date3)],(DGPS186.bed(2:3)-DGPS186.bed(2)).*1000,'--','color',[0,0.5,0]);
plot([datenum(DGPS.date2),datenum(DGPS.date3)],(DGPS186.top(2:3)-DGPS186.top(2)).*1000,'-.','color',[0,0.5,0]);

plot([datenum(DGPS.date2),datenum(DGPS.date3)],(DGPS184.bed(2:3)-DGPS184.bed(2)).*1000,'--','color',[0.75,0.75,0.75]);
plot([datenum(DGPS.date2),datenum(DGPS.date3)],(DGPS184.top(2:3)-DGPS184.top(2)).*1000,'-.','color',[0.75,0.75,0.75]);

plot([datenum(DGPS.date2),datenum(DGPS.date3)],(DGPS185.bed(2:3)-DGPS185.bed(2)).*1000,'--','color',[0.25,0.25,1]);
plot([datenum(DGPS.date2),datenum(DGPS.date3)],(DGPS185.top(2:3)-DGPS185.top(2)).*1000,'-.','color',[0.25,0.25,1]);

datetick('x','dd-mm-yyyy');
box on; grid on

ylabel('bed level variation [mm]','fontsize',14)
xlabel('time [dd-mm-yyyy]','fontsize',14);
legend('A 60m - top bedform','A 60m - bottom bedform','A 100m','B 100m','C 100m', ...
    'A 60m - top bedform (24h mov. avg.)','A 60m - bottom bedform (24h mov. avg.)', ...
    'A 100m (24h mov. avg.)', ...
    'B 100m (24h mov. avg.)','C 100m (24h mov. avg.)','DGPS bed SED', 'DGPS top SED',...
    'location','northeast');
set(gca,'fontsize',14)
%% FFT analysis
Fs = 1/1800;

SED182_z = SED182(:,2)-SED182_ref;
SED182_z(isnan(SED182_z)) = 0;
L_SED182 = length(SED182_z);
n_SED182 = 2^nextpow2(L_SED182);
Y_SED182 = fft(SED182_z,n_SED182);
f_SED182 = Fs*(0:(n_SED182/2))/n_SED182;
P_SED182 = abs(Y_SED182/n_SED182);

SED183_z = SED183(:,2)-SED183_ref;
SED183_z(isnan(SED183_z)) = 0;
L_SED183 = length(SED183_z);
n_SED183 = 2^nextpow2(L_SED183);
Y_SED183 = fft(SED183_z,n_SED183);
f_SED183 = Fs*(0:(n_SED183/2))/n_SED183;
P_SED183 = abs(Y_SED183/n_SED183);

SED184_z = SED184(:,2)-SED184_ref;
SED184_z(isnan(SED184_z)) = 0;
L_SED184 = length(SED184_z);
n_SED184 = 2^nextpow2(L_SED184);
Y_SED184 = fft(SED184_z,n_SED184);
f_SED184 = Fs*(0:(n_SED184/2))/n_SED184;
P_SED184 = abs(Y_SED184/n_SED184);

SED185_z = SED185(:,2)-SED185_ref;
SED185_z(isnan(SED185_z)) = 0;
L_SED185 = length(SED185_z);
n_SED185 = 2^nextpow2(L_SED185);
Y_SED185 = fft(SED185_z,n_SED185);
f_SED185 = Fs*(0:(n_SED185/2))/n_SED185;
P_SED185 = abs(Y_SED185/n_SED185);

%% Frequency analysis
% Make one dataset for loop calculations (4 - 2 - 6 - 5 - 3)
data_merge{1,1} = SED184_comb;
data_merge{2,1} = SED182_comb;
data_merge{3,1} = SED186_comb;
data_merge{4,1} = SED185_comb;
data_merge{5,1} = SED183_comb;

n = 48; % average every n values

% Make average every n values
for j = 1;
    data_merge_day{j} = arrayfun(@(k) nanmean(data_merge{j,1}((k:k+n-1),1)),1:n:length(data_merge{j,1}(:,1))-n+1)'; % the averaged vector
    nanfil{j} = find(isnan(data_merge_day{j}))'
    nanfil_adj{j} = nanfil{j} - [0:1:length(nanfil{j})-1];
    diff_vec{j} = diff([inf,nanfil_adj{j}])~=0;
     nanfil_adj_res{j} = [nanfil{j}(logical(diff_vec{j})) ;...
         accumarray(cumsum(diff_vec{j}(:)),1).'];
     
     %interp NaN values
     for k = 1:size(nanfil_adj_res{j},2)
        interp_vals{j,k} = interp1([nanfil_adj_res{j}(1,k)-1,nanfil_adj_res{j}(1,k)+nanfil_adj_res{j}(2,k)],...
            [data_merge_day{j}(nanfil_adj_res{j}(1,k)-1),...
            data_merge_day{j}(nanfil_adj_res{j}(1,k)+nanfil_adj_res{j}(2,k))],...
           [nanfil_adj_res{j}(1,k):1:nanfil_adj_res{j}(1,k)+nanfil_adj_res{j}(2,k)-1]);
        data_merge_day{j}(nanfil_adj_res{j}(1,k):...
            nanfil_adj_res{j}(1,k)+nanfil_adj_res{j}(2,k)-1) = interp_vals{j,k};
     end
end

% FFT transform
for j = 1;
%     data_merge_day{j}(isnan(data_merge_day{j})) = 0;
    
    data_merge_day{j} = diff(data_merge_day{j}); %take the difference
    
    L_dat(j) = length(data_merge_day{j});
    data_merge_day_fft{j} = fft(data_merge_day{j});
    P2{j} = abs(data_merge_day_fft{j}/L_dat(j));
    P1{j} = P2{j}(1:L_dat(j)/2+1);
    P1{j}(2:end-1) = 2*P1{j}(2:end-1);
    f{j} =  (1/(3600*24))*(0:(L_dat(j)/2))/L_dat(j);
%     f{j} =  (1)*(0:(L_dat(j)/2))/L_dat(j);
end

% Cut off at daily to weekly variations
CO_Freq = 50;


for j = 1
    total_std = std(data_merge_day{j})
    
    S{j} = fftshift(fft(data_merge_day{j}));
    
    S_clearlow{j} = S{j};
    S_clearlow{j}(1:CO_Freq) = 0;
    S_clearlow{j}(end-CO_Freq+2:end) = 0;
    S_clearlow{j} = fftshift(S_clearlow{j});
    S_cleared_low{j} = ifft(S_clearlow{j});
    low_std = std(S_cleared_low{j})
    
    S_clearhigh{j} = S{j};
    S_clearhigh{j}(1:round(length(S{j})/2)-CO_Freq) = 0;
    S_clearhigh{j}(round(length(S{j})/2)+CO_Freq:end) = 0;
    S_clearhihg{j} = fftshift(S_clearhigh{j});
    S_cleared_high{j} = ifft(S_clearhigh{j});
    high_std = std(S_cleared_high{j})
    
    freq_x{j} = [-fliplr(f{j}(2:end)),f{j}]';
end



for j = 1
figure;

subplot(3,2,1)
plot(data_merge_day{j})
title('original signal')

subplot(3,2,2)
plot(freq_x{j},abs(S{j}))
title('frequency spectrum')
% xlim([0,3e-5]);

subplot(3,2,3)
plot(freq_x{j},abs(S_clearlow{j}))
title('frequency spectrum low cleared')

subplot(3,2,4)
plot(1:1:377,S_cleared_low{j})
title('low cleared signal')


subplot(3,2,5)
plot(freq_x{j},abs(S_clearhigh{j}))
title('frequency spectrum high cleared')

subplot(3,2,6)
plot(1:1:377,S_cleared_high{j})
title('high cleared signal')
end

figure;
plot(1:1:377,data_merge_day{j},'k'); hold on
plot(1:1:377,S_cleared_low{j},':b');
plot(1:1:377,S_cleared_high{j},'--r');


%% Plot data
figure;

subplot(2,2,1)
plot(f_SED184,P_SED184(1:n_SED184/2+1)) 
grid on; box on
xlim([0,0.3e-4]);
ylim([0,30]);
ylabel('|P|','fontsize',14);
title('A 60m - top bedform','fontsize',14);
set(gca,'fontsize',14)

subplot(2,2,2)
plot(f_SED182,P_SED182(1:n_SED182/2+1)) 
grid on; box on
xlim([0,0.3e-4]);
ylim([0,30]);
title('A 60m - bottom bedform','fontsize',14);
set(gca,'fontsize',14)

subplot(2,2,3)
plot(f_SED185,P_SED185(1:n_SED185/2+1)) 
grid on; box on
xlim([0,0.3e-4]);
ylim([0,30]);
ylabel('|P|','fontsize',14);
xlabel('Frequency','fontsize',14);
title('B 100m','fontsize',14);
set(gca,'fontsize',14)

subplot(2,2,4)
plot(f_SED183,P_SED183(1:n_SED183/2+1)) 
grid on; box on
xlim([0,0.3e-4]);
ylim([0,30]);
xlabel('Frequency','fontsize',14);
title('C 100m','fontsize',14);
set(gca,'fontsize',14)

%% plot water level and wave height
figure;
subplot(2,1,1)
plot(P.SED184_0001.WL.t,P.SED184_0001.WL.Val,'color',[0.75,0.75,0.75]);
hold on
plot(P.SED185_0001.WL.t,P.SED185_0001.WL.Val,'color',[0.25,0.25,1]);
plot(P.SED183_0001.WL.t,P.SED183_0001.WL.Val,'color',[1,0.25,0.25]);
datetick('x'); grid on; box on
ylabel('water level [m]')
legend('A 60m','B 100m','C 100m','location','northwest');

subplot(2,1,2)
plot(P.SED183_0001.Wave.t,P.SED183_0001.Wave.Hm0,'color',[1,0.25,0.25]);
hold on
plot(P.SED184_0001.Wave.t,P.SED184_0001.Wave.Hm0,'color',[0.75,0.75,0.75]);
plot(P.SED185_0001.Wave.t,P.SED185_0001.Wave.Hm0,'color',[0.25,0.25,1]);
datetick('x'); grid on; box on; ylim([0,0.25]);
ylabel('Hm0 [m]')

%% Combine morpho and hydro
XMarks = datenum(SED184(1,6:11)):(datenum([2001,1,8])-datenum([2001,1,1])):datenum(SED184(end,6:11));

% A 60m - top bedform
figure;
subplot(5,1,1)
plot(P.SED184_0001.WL.t,P.SED184_0001.WL.Val,'color',[0.75,0.75,0.75]);
set(gca,'xtick',XMarks,'xticklabel',XMarks); datetick('x','keepticks');  grid on; box on; ylim([0.4, 1.5]); xlim([datenum(SED184(1,6:11)),datenum(SED184(end,6:11))]);
ylabel('water level [m]'); title('A 60m - top bedform')

subplot(5,1,2)
plot(P.SED184_0001.Wave.t,P.SED184_0001.Wave.Hm0,'color',[0.75,0.75,0.75]);
set(gca,'xtick',XMarks,'xticklabel',XMarks); datetick('x','keepticks');  grid on; box on;  ylim([0,0.25]); xlim([datenum(SED184(1,6:11)),datenum(SED184(end,6:11))]);
ylabel('Hm0 [m]')

subplot(5,1,3)
plot(datenum(SED184(:,6:11)),SED184(:,2)-SED184(SED184_ref,2),'.','color',[0.75,0.75,0.75]);
set(gca,'xtick',XMarks,'xticklabel',XMarks); datetick('x','keepticks');  grid on; box on; ylim([-20, 100]); xlim([datenum(SED184(1,6:11)),datenum(SED184(end,6:11))]);
ylabel('bed level change [mm]')

subplot(5,1,4)
plot(datenum(weather_Tvec),weather_dat(:,4),'.','color',[0.75,0.75,0.75]);
set(gca,'xtick',XMarks,'xticklabel',XMarks); datetick('x','keepticks');  grid on; box on; ylim([-20, 100]); xlim([datenum(SED184(1,6:11)),datenum(SED184(end,6:11))]);
ylabel('wind direction [deg]')

subplot(5,1,5)
plot(datenum(weather_Tvec),weather_dat(:,5),'.','color',[0.75,0.75,0.75]);
set(gca,'xtick',XMarks,'xticklabel',XMarks); datetick('x','keepticks');  grid on; box on; ylim([-20, 100]); xlim([datenum(SED184(1,6:11)),datenum(SED184(end,6:11))]);
ylabel('precipitation [0.1 mm]')

% A 60m - bottom bedform
figure;
subplot(3,1,1)
plot(P.SED184_0001.WL.t,P.SED184_0001.WL.Val,'color',[0.4,0.4,0.4]);
set(gca,'xtick',XMarks,'xticklabel',XMarks); datetick('x','keepticks');  grid on; box on; ylim([0.4, 1.5]); xlim([datenum(SED184(1,6:11)),datenum(SED184(end,6:11))]);
ylabel('water level [m]'); title('A 60m - bottom bedform (using pressure of top bedform)')

subplot(3,1,2)
plot(P.SED184_0001.Wave.t,P.SED184_0001.Wave.Hm0,'color',[0.4,0.4,0.4]);
set(gca,'xtick',XMarks,'xticklabel',XMarks); datetick('x','keepticks');  grid on; box on;  ylim([0,0.25]); xlim([datenum(SED184(1,6:11)),datenum(SED184(end,6:11))]);
ylabel('Hm0 [m]')

subplot(3,1,3)
plot(datenum(SED182(:,6:11)),SED182(:,2)-SED182(SED182_ref,2),'.','color',[0.4,0.4,0.4]);
set(gca,'xtick',XMarks,'xticklabel',XMarks); datetick('x','keepticks');  grid on; box on; ylim([-20, 100]); xlim([datenum(SED184(1,6:11)),datenum(SED184(end,6:11))]);
ylabel('bed level change [mm]')

% B 100m
figure;
subplot(3,1,1)
plot(P.SED185_0001.WL.t,P.SED185_0001.WL.Val,'color',[0.25,0.25,1]);
set(gca,'xtick',XMarks,'xticklabel',XMarks); datetick('x','keepticks');  grid on; box on; ylim([0.4, 1.5]); xlim([datenum(SED184(1,6:11)),datenum(SED184(end,6:11))]);
ylabel('water level [m]'); title('B 100m')

subplot(3,1,2)
plot(P.SED185_0001.Wave.t,P.SED185_0001.Wave.Hm0,'color',[0.25,0.25,1]);
set(gca,'xtick',XMarks,'xticklabel',XMarks); datetick('x','keepticks');  grid on; box on;  ylim([0,0.25]); xlim([datenum(SED184(1,6:11)),datenum(SED184(end,6:11))]);
ylabel('Hm0 [m]')

subplot(3,1,3)
plot(datenum(SED185(:,6:11)),SED185(:,2)-SED185(SED185_ref,2),'.','color',[0.25,0.25,1]);
set(gca,'xtick',XMarks,'xticklabel',XMarks); datetick('x','keepticks');  grid on; box on; ylim([-20, 100]); xlim([datenum(SED184(1,6:11)),datenum(SED184(end,6:11))]);
ylabel('bed level change [mm]')

% C 100m
figure;
subplot(3,1,1)
plot(P.SED183_0001.WL.t,P.SED183_0001.WL.Val,'color',[1,0.25,0.25]);
set(gca,'xtick',XMarks,'xticklabel',XMarks); datetick('x','keepticks');  grid on; box on; ylim([0.4, 1.5]); xlim([datenum(SED184(1,6:11)),datenum(SED184(end,6:11))]);
ylabel('water level [m]'); title('C 100m')

subplot(3,1,2)
plot(P.SED183_0001.Wave.t,P.SED183_0001.Wave.Hm0,'color',[1,0.25,0.25]);
set(gca,'xtick',XMarks,'xticklabel',XMarks); datetick('x','keepticks');  grid on; box on;  ylim([0,0.25]); xlim([datenum(SED184(1,6:11)),datenum(SED184(end,6:11))]);
ylabel('Hm0 [m]')

subplot(3,1,3)
plot(datenum(SED183(:,6:11)),SED183(:,2)-SED183(SED185_ref,2),'.','color',[1,0.25,0.25]);
set(gca,'xtick',XMarks,'xticklabel',XMarks); datetick('x','keepticks');  grid on; box on; ylim([-20, 100]); xlim([datenum(SED184(1,6:11)),datenum(SED184(end,6:11))]);
ylabel('bed level change [mm]')

%% plot combined data 
figure;
plot(datenum(SED184_combT(~isnan(SED184_comb),:)),SED184_comb(~isnan(SED184_comb)),':','color',[0.75,0.75,0.75],'linewidth',2);
hold on;
plot(datenum(SED182_combT(~isnan(SED182_comb),:)),SED182_comb(~isnan(SED182_comb)),':','color',[0.4,0.4,0.4],'linewidth',2);
plot(datenum(SED186_combT(~isnan(SED186_comb),:)),SED186_comb(~isnan(SED186_comb)),':','color',[0,0.5,0],'linewidth',2);
plot(datenum(SED185_combT(~isnan(SED185_comb),:)),SED185_comb(~isnan(SED185_comb)),':','color',[0.25,0.25,1],'linewidth',2);
plot(datenum(SED183_combT(~isnan(SED183_comb),:)),SED183_comb(~isnan(SED183_comb)),':','color',[1,0.25,0.25],'linewidth',2);

plot([datenum(SED186_combT(301,:)),datenum(SED186_combT(301,:))],[-150, 150],'k'); % boundary measurement period

% plot(datenum(SED184_2(:,6:11)),SED184_2_maday,'color',[0.5,0.5,0.5]);
% plot(datenum(SED182_2(:,6:11)),SED182_2_maday,'color',[0,0,0]);
% plot(datenum(SED186_2(:,6:11)),SED186_2_maday,'color','g');
% plot(datenum(SED185_2(:,6:11)),SED185_2_maday,'b');
% plot(datenum(SED183_2(:,6:11)),SED183_2_maday,'r');

datetick('x','dd-mm-yyyy');
box on; grid on
% xlim([datenum(SED182_combT(1,1)),datenum(SED186_combT(end,1))]);
ylim([-150,150]);

ylabel('bed level variation [mm]','fontsize',14)
xlabel('time [dd-mm-yyyy]','fontsize',14);
legend('A 60m - top bedform','A 60m - bottom bedform','A 100m','B 100m','C 100m', ...
    'A 60m - top bedform (24h mov. avg.)','A 60m - bottom bedform (24h mov. avg.)', ...
    'A 100m (24h mov. avg.)', 'B 100m (24h mov. avg.)','C 100m (24h mov. avg.)', ...
    'location','northeast');
set(gca,'fontsize',14)
